# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DataBlock.proto

import sys
#import os
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
#import google.protobuf
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
#from packaging import version


# parsed_version = version.parse(google.protobuf.__version__)
# target_version = version.parse("3.20.0")
# if parsed_version >= target_version:


# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x44\x61taBlock.proto\"E\n\x0cStringResult\x12\x11\n\terrorCode\x18\x01 \x01(\x05\x12\x14\n\x0c\x65rrorMessage\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"M\n\x0f\x42yteArrayResult\x12\x11\n\terrorCode\x18\x01 \x01(\x05\x12\x14\n\x0c\x65rrorMessage\x18\x02 \x01(\t\x12\x11\n\tbyteArray\x18\x03 \x01(\x0c\"h\n\x18StringAndByteArrayResult\x12\x11\n\terrorCode\x18\x01 \x01(\x05\x12\x14\n\x0c\x65rrorMessage\x18\x02 \x01(\t\x12\x10\n\x08\x64\x61taName\x18\x03 \x01(\t\x12\x11\n\tbyteArray\x18\x04 \x01(\x0c\"[\n\x0e\x46ileInfoResult\x12\x11\n\terrorCode\x18\x01 \x01(\x05\x12\x14\n\x0c\x65rrorMessage\x18\x02 \x01(\t\x12\x0e\n\x06isFile\x18\x03 \x01(\x08\x12\x10\n\x08\x66ileSize\x18\x04 \x01(\x03\"\x94\x01\n\tMapResult\x12\x11\n\terrorCode\x18\x01 \x01(\x05\x12\x14\n\x0c\x65rrorMessage\x18\x02 \x01(\t\x12,\n\tresultMap\x18\x03 \x03(\x0b\x32\x19.MapResult.ResultMapEntry\x1a\x30\n\x0eResultMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42)\n\x1c\x63n.gov.cma.cimiss.gds.serverB\tDataBlockb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DataBlock_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034cn.gov.cma.cimiss.gds.serverB\tDataBlock'
  _globals['_MAPRESULT_RESULTMAPENTRY']._options = None
  _globals['_MAPRESULT_RESULTMAPENTRY']._serialized_options = b'8\001'
  _globals['_STRINGRESULT']._serialized_start=19
  _globals['_STRINGRESULT']._serialized_end=88
  _globals['_BYTEARRAYRESULT']._serialized_start=90
  _globals['_BYTEARRAYRESULT']._serialized_end=167
  _globals['_STRINGANDBYTEARRAYRESULT']._serialized_start=169
  _globals['_STRINGANDBYTEARRAYRESULT']._serialized_end=273
  _globals['_FILEINFORESULT']._serialized_start=275
  _globals['_FILEINFORESULT']._serialized_end=366
  _globals['_MAPRESULT']._serialized_start=369
  _globals['_MAPRESULT']._serialized_end=517
  _globals['_MAPRESULT_RESULTMAPENTRY']._serialized_start=469
  _globals['_MAPRESULT_RESULTMAPENTRY']._serialized_end=517
# @@protoc_insertion_point(module_scope)
